bmem.cov: Calculate the covariance matrix based on a given ram model

View source: R/bmem.R

bmem.covR Documentation

Calculate the covariance matrix based on a given ram model

Description

Can be used to simulated data for an SEM model.

Usage

bmem.cov(ram,obs.variables,moment=FALSE, debug=FALSE)

Arguments

ram

An ram model

obs.variables

Names of the observed variables

moment

Whether to use the mean structure

debug

debug mode


bmem documentation built on Sept. 1, 2026, 1:07 a.m.